@@ -98,15 +98,19 @@ def import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10):
         # give other threads a chance to run: commit will release the pool, get
         # it back afterwards
         session.commit()
-        session.set_pool()
     except:
+        # clear in cases new files have been added in cache, but entities will
+        # be rollbacked
+        repohdlr.vf_path_cache.clear()
         try:
+            vcsrepo._cw.set_pool() # ensure a pool is set
             title = vcsrepo.dc_title()
         except:
             title = str(vcsrepo)
         repohdlr.exception(
             'error while importing content for vcs repo %s', title)
         session.rollback()
+    session.set_pool()
 
 
 def set_at_revision(session, reid, safetybelt=False):
