@@ -1,7 +1,7 @@
 """entity classes for vcsfile content types
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,6 +9,7 @@ import os.path as osp
 
 from logilab.common.decorators import cached, clear_cache
 from logilab.common.compat import any
+from logilab.common.deprecation import deprecated
 
 from cubicweb import QueryError, Binary, Unauthorized
 from cubicweb.selectors import is_instance
@@ -264,7 +265,7 @@ class VersionedFile(AnyEntity):
 
     @property
     def revisions(self):
-        """return an ordered list of revision contents for this file"""
+        """return an ordered list of versions'content for this file"""
         return self.reverse_content_for
 
     @property
@@ -380,17 +381,40 @@ class DeletedVersionContent(AnyEntity):
     def head(self):
         return self.file.branch_head(self.rev.branch)
 
+    def iter_parent_versions(self):
+        done = set([self.eid])
+        todo = [self]
+        while todo:
+            head = todo.pop(0)
+            for parent in head.previous_versions():
+                if not parent.eid in done:
+                    done.add(parent.eid)
+                    todo.append(parent)
+                    yield parent
+
+    def previous_versions(self):
+        return tuple(self._cw.execute(
+            'DISTINCT Any VC ORDERBY VC DESC WHERE '
+            'R parent_revision PR, X at_revision R, VC at_revision PR, '
+            'VC content_for F, X content_for F, '
+            'NOT VC eid %(x)s, X eid %(x)s', {'x': self.eid}).entities())
+
+    @deprecated('[vcsfile 1.7.1] use previous_versions() instead')
     def previous_version(self, branch=_MARKER):
-        if branch is _MARKER:
-            branch = self.rev.branch
-        rset = self._cw.execute('Any PV,R,PVR,VF ORDERBY PVR DESC LIMIT 1 '
-                                'WHERE PV from_revision R, R revision PVR, '
-                                'R branch %(b)s, PV content_for VF, '
-                                'R revision < %(r)s, VF eid %(vf)s',
-                                {'r': self.rev.revision, 'b': branch,
-                                 'vf': self.file.eid})
-        if rset:
-            return rset.get_entity(0, 0)
+        pver = self.previous_versions()
+        return pver and pver[0] or None
+
+    def next_versions(self):
+        return tuple(self._cw.execute(
+            'DISTINCT Any VC ORDERBY VC ASC WHERE '
+            'PR parent_revision R, X at_revision R, VC at_revision PR, '
+            'VC content_for F, X content_for F, '
+            'NOT VC eid %(x)s, X eid %(x)s', {'x': self.eid}).entities())
+
+    @deprecated('[vcsfile 1.7.1] use next_versions() instead')
+    def next_version(self, branch=_MARKER):
+        nver = self.next_versions()
+        return nver and nver[0] or None
 
     def next_version(self, branch=_MARKER):
         if branch is _MARKER:
