@@ -122,9 +122,9 @@ class ServerStartupHook(hook.Hook):
             session = repo.internal_session()
             try:
                 reposrset = session.execute(
-                    'Any R, RT, RLC, RSU, RP, RIRC WHERE R is Repository, '
+                    'Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
                     'R type "mercurial", NOT (R local_cache NULL AND R path NULL),'
-                    'R type RT, R local_cache RLC, R source_url RSU, R path RP,'
+                    'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
                     'R import_revision_content RIRC, R cw_source S, S name "system"')
                 for vcsrepo in reposrset.entities():
                     try:
