@@ -33,9 +33,6 @@ class VCSRepository(object):
             fspath = path.encode(encoding)
         else:
             fspath = path
-        if not exists(fspath):
-            msg = _('%s does not exist on the file system')
-            raise bridge.VCSException(eid, 'path', msg, path)
         try:
             fspath = self.canonicalize(fspath)
         except:
