@@ -1,7 +1,7 @@
 """primary views for entity types defined by the vcsfile package
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,9 +9,9 @@ _ = unicode
 
 from logilab.mtconverter import TransformError, xml_escape
 
-from cubicweb import tags
+from cubicweb import Unauthorized, tags
 from cubicweb.mttransforms import ENGINE
-from cubicweb.selectors import is_instance
+from cubicweb.selectors import is_instance, score_entity
 from cubicweb.view import EntityView
 from cubicweb.web import uicfg
 from cubicweb.web.views import (ibreadcrumbs, idownloadable,
@@ -90,7 +90,7 @@ class RepositoryInfoTab(tabs.PrimaryTab):
 
 class RepositoryFilesTab(EntityView):
     __regid__ = 'repositoryfiles_tab'
-    __select__ = is_instance('Repository')
+    __select__ = is_instance('Repository') & score_entity(lambda x: x.import_revision_content)
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -261,29 +261,33 @@ class DVCIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
 class RevisionIPrevNextAdapter(navigation.IPrevNextAdapter):
     __select__ = is_instance('Revision')
 
-    def previous_entity(self): # IPrevNext
-        # may have multiple parents, take the first one in the same branch...
-        rset = self._cw.execute('Any X LIMIT 1 WHERE R parent_revision X , '
-                                'R eid %(r)s, X branch %(branch)s',
-                                {'r': self.entity.eid, 'branch': self.entity.branch})
-        if rset:
-            return rset.get_entity(0, 0)
+    def previous_entity(self):
+        # may have multiple parents, give priority to the one in the same
+        # branch.
+        parent = None
+        for parent in self.entity.parent_revision:
+            if parent.branch == self.entity.branch:
+                return parent
+        return parent
 
-    def next_entity(self): # IPrevNext
-        # may have multiple children, take the first one in the same branch...
-        rset = self._cw.execute('Any X LIMIT 1 WHERE X parent_revision R , '
-                                'R eid %(r)s, X branch %(branch)s',
-                                {'r': self.entity.eid, 'branch': self.entity.branch})
-        if rset:
-            return rset.get_entity(0, 0)
+    def next_entity(self):
+        # may have multiple children, give priority to the one in the same
+        # branch.
+        child = None
+        for child in self.entity.reverse_parent_revision:
+            if child.branch == self.entity.branch:
+                return child
+        return child
 
 
 class DVCIPrevNextAdapter(navigation.IPrevNextAdapter):
     __select__ = is_instance('VersionContent', 'DeletedVersionContent')
 
     def previous_entity(self):
-        return self.entity.previous_version()
+        pver = self.entity.previous_versions()
+        return pver and pver[0] or None
 
     def next_entity(self):
-        return self.entity.next_version()
+        nver = self.entity.next_versions()
+        return nver and nver[0] or None
 
